Crate bt_logger

Crate bt_logger 

Modules

macros

Macros

get_error
Get a Error Message. get_fatal!(function name, message, message arguments)
get_fatal
Get a Fatal Error Message. get_fatal!(function name, message, message arguments)
log_debug
Debugging message. log_debug!(function name, message, message arguments)
log_error
Log an Error Message. log_error!(function name, message, message arguments)
log_fatal
Log a Fatal Error. log_fatal!(function name, message, message arguments)
log_info
Log an Informational message. log_info!(function name, message, message arguments)
log_trace
Trace message. log_trace!(function name, message, message arguments)
log_verbose
Very verbose message. log_verbose!(function name, message, message arguments)
log_warning
Log a Warning message. log_warning!(function name, message, message arguments)

Structs

Logger
Logger Represents a logger instance with its configuration. log_tag: The tag used in log messages log_app: The application name used in log messages current_log_level_value: The current log level value (0-100) output_destination: The output destination for log messages (StdError, StdOut, or StdBoth)

Enums

LogLevel
LogLevel Represents the different levels of log severity. The values are ordered from lowest to highest severity. NONE = No logging, FATAL = Fatal error, ERROR = Error message, WARN = Warning message, INFO = Informational message, DEBUG = Debugging message, TRACE = Trace message, VERBOSE = Very verbose message
LogTarget
LogTarget Represents the different output destinations for log messages. STD_ERROR: Logs to stderr STD_OUT: Logs to stdout STD_BOTH: Logs to both stdout and stderr NONE: Does not send log to any of the STD.

Functions

build_logger
Build the logger. Run this function first Configures a global logger instance based on the provided environment variables and options.
build_logger_args
Build the logger. Run this function first Builds a logger configuration based on the provided arguments.
build_logger_env
Build the logger using environment variables and default to parameters. Run this function first Configures a global logger instance based on the provided environment variables and options.
get_logger