Logger
Represents a logger instance with its configuration.
log_tag: The tag used in log messages
log_app: The application name used in log messages
current_log_level_value: The current log level value (0-100)
output_destination: The output destination for log messages (StdError, StdOut, or StdBoth)
LogLevel
Represents the different levels of log severity. The values are ordered from lowest to highest severity.
NONE = No logging,
FATAL = Fatal error,
ERROR = Error message,
WARN = Warning message,
INFO = Informational message,
DEBUG = Debugging message,
TRACE = Trace message,
VERBOSE = Very verbose message
LogTarget
Represents the different output destinations for log messages.
STD_ERROR: Logs to stderr
STD_OUT: Logs to stdout
STD_BOTH: Logs to both stdout and stderr
NONE: Does not send log to any of the STD.
Build the logger using environment variables and default to parameters. Run this function first
Configures a global logger instance based on the provided environment variables and options.